clear
clear matrix
set more off, perma  
adopath + "C:\Users\Administrator\Desktop"
cd c:\Users\Administrator\Desktop   // stata启动后自动进入该目录 
capture clear 
use "C:\Users\Administrator\Desktop\数据.dta"




*-----------------------------------------------------------------------------------------------------------------
*-----------------------------------------------------------------------------------------------------------------
****************************************第一部分：变量和样本处理***************************************
*-----------------------------------------------------------------------------------------------------------------
*-----------------------------------------------------------------------------------------------------------------

                       
********************************************************

*(1)将字符型变量code转换为数值型变量id，然后设定面板数据的截面与时间维度

encode code, gen(id)

xtset id year	

*(2)设置国际创业活跃度变量intea为tea与intent的乘积再除以100；设置管制环境变量reg为reg1、reg2、reg3的算术平均；设置制度环境变量ins为reg、cog、nor的算术平均

g intea=(tea*intent)/100

g reg=(reg1+reg2+reg3)/3

g ins=(reg+cog+nor)/3

*(3)分别取变量gni、gdp、trade的对数及滞后一期，分别取变量ins、reg、nor、cog、fear、rd、gdpgr、fdis、fdi的滞后一期

g ln_gni=ln(gni)
g ln_gdp=ln(gdp)
g ln_trade=ln(trade)
g ln_gni_lag=L.ln_gni
g ln_gdp_lag=L.ln_gdp
g ln_trade_lag=L.ln_trade
g ins_lag=L.ins
g reg_lag=L.reg
g nor_lag=L.nor
g cog_lag=L.cog
g fear_lag=L.fear
g rd_lag=L.rd
g gdpgr_lag=L.gdpgr
g fdi_lag=L.fdi
g fdis_lag=L.fdis

*(4)分别中心化变量fdi、fdis、ins、reg、nor、cog、fear、rd，然后设置中心化后的FDI流入与各变量的交乘项并取滞后一期

center fdi fdis ins reg cog nor fear rd

g c_insfdi=c_ins*c_fdi
g c_insfdis=c_ins*c_fdis
g c_regfdi=c_reg*c_fdi
g c_regfdis=c_reg*c_fdis
g c_norfdi=c_nor*c_fdi
g c_norfdis=c_nor*c_fdis
g c_cogfdi=c_cog*c_fdi
g c_cogfdis=c_cog*c_fdis
g c_fearfdi=c_fear*c_fdi
g c_fearfdis=c_fear*c_fdis
g c_rdfdi=c_rd*c_fdi
g c_rdfdis=c_rd*c_fdis

g c_insfdi_lag=L.c_insfdi
g c_insfdis_lag=L.c_insfdis
g c_regfdi_lag=L.c_regfdi
g c_regfdis_lag=L.c_regfdis
g c_norfdi_lag=L.c_norfdi
g c_norfdis_lag=L.c_norfdis
g c_cogfdi_lag=L.c_cogfdi
g c_cogfdis_lag=L.c_cogfdis
g c_fearfdi_lag=L.c_fearfdi
g c_fearfdis_lag=L.c_fearfdis
g c_rdfdi_lag=L.c_rdfdi
g c_rdfdis_lag=L.c_rdfdis
 

*(5)将样本期限定为2003-2013，并删除样本期内intea值缺失的观察项

keep if year>=2003 & year<=2013 

drop if intea==.

table country

*(6)删除样本期内intea值少于4期的国家（地区），进而删除制度环境及其各维度的值少于4期的国家（地区），最后剩下52个国家（地区）

drop if country=="Angola" | country=="Austria"     | country=="Barbados"    | country=="Dominican Republic" |   ///
     country=="Egypt"  | country=="Ghana"       | country=="Hong Kong"   | country=="India" |   ///
	 country=="Japan"  | country=="Lithuania"   | country=="New Zealand" | country=="Pakistan"|    ///
	 country=="Romania"  | country=="Slovakia"   | country=="Tunisia"    | country=="Zambia" |country=="Czech Republic"

table country

save 1.dta, replace


******************************************************************************************************
********************************************第二部分：基本统计分析——表2*****************************
******************************************************************************************************

*(1)变量的描述性统计

use 1.dta,clear
ssc install logout	   
logout,save(statistic) excel  dec(4) replace: ///
tabstat  intea fdi ins reg cog nor ln_gdp gdpgr ln_gni ln_trade, ///
	   s(n mean sd min max) format(%6.4f) column(statis)    

*(2)多重共线性检验

quietly  reg intea fdi ins reg  nor cog ln_gdp gdpgr ln_gni ln_trade
logout,save (var_vif) excel replace: vif  //方差膨胀因子检验	

*(3)相关系数矩阵

logout, save(var_corr)  excel replace: ///
        pwcorr intea fdi ins reg nor cog ln_gdp gdpgr ln_gni ln_trade, star(.1) //标注显著性在10%及以上的值	
		

		
*-----------------------------------------------------------------------------------------------------------------
*-----------------------------------------------------------------------------------------------------------------
****************************************第三部分：基准回归与内生性检验——表3、表4***********************************
*-----------------------------------------------------------------------------------------------------------------
*-----------------------------------------------------------------------------------------------------------------

                       
*(1)基准回归：外资流入、总的制度环境及其管制维度和规范维度分别正向影响国际创业；外资流入、总的制度环境及其规范维度均同时正向影响国际创业

use 1.dta, clear
xtset id year 
qui tab year, gen(yr)


reg intea fdi ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10, r
est store model_1

reg intea ins ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,r
est store model_2

reg intea reg ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,r
est store model_3

reg intea nor ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,r
est store model_4

reg intea cog ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,r
est store model_5

reg intea fdi ins ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,r
est store model_6

reg intea fdi reg ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,r
est store model_7

reg intea fdi nor ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,r
est store model_8

reg intea fdi cog ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,r
est store model_9

local m "model_1  model_2  model_3  model_4  model_5  model_6  model_7  model_8  model_9"
esttab `m' , mtitle(`m')  nogap compress s(N r2) star(* 0.1 ** 0.05 *** 0.01) ///
             t(%6.2f) b(%6.4f) replace
esttab `m'   using table3.csv, mtitle(`m')  nogap compress s(N r2) ///
             t(%6.2f) b(%6.4f) star(* 0.1 ** 0.05 *** 0.01) replace 


*(2)调节效应：外资流入正向调节总的制度环境与国际创业的关系，这主要通过调节东道国的管制环境实现

use 1.dta, clear
xtset id year 
qui tab year, gen(yr)

reg intea fdi ins c_insfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10
est store model_1

reg intea fdi reg c_regfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10
est store model_2

reg intea fdi nor c_norfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10
est store model_3

reg intea fdi cog c_cogfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10
est store model_4

local m "model_1  model_2  model_3  model_4"
esttab `m' , mtitle(`m')  nogap compress s(N r2) star(* 0.1 ** 0.05 *** 0.01) ///
             t(%6.2f) b(%6.4f) replace
esttab `m'   using table4.csv, mtitle(`m')  nogap compress s(N r2) ///
             t(%6.2f) b(%6.4f) star(* 0.1 ** 0.05 *** 0.01) replace 



*(3)模型选择：在混合回归模型与固定效应模型之间应选择固定效应模型；在混合回归模型与随机效应模型之间应选择随机效应模型；在固定效应模型与随机效应模型之间应选择固定效应模型

use 1.dta, clear
xtset id year 


reg intea fdi ins c_insfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag 
est store ols

xtreg intea fdi ins c_insfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag ,fe
est store fe

xtreg intea fdi ins c_insfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag ,re
est store re
xttest0

hausman fe re 
*检验结果显示，在百分之五的水平上拒绝随机效应模型。因此，应选择固定效应模型，或进行工具变量估计。但固定效应模型的总体拟合度未通过显著性检验，于是考虑工具变量估计，并做内生性检验

                       
*(4)当总的制度环境是唯一解释变量时，总制度环境的滞后一期即作为总制度环境的工具变量

*采用2sls方法.首先检验制度环境的工具变量的有效性，并做内生性检验

use 1.dta, clear
xtset id year 

reg intea ins ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag 
ivregress 2sls intea ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag (ins=ins_lag),first r
estat endogenous  
*稳健的DWH检验显示，P=0.7548，即不能拒绝ins是外生变量的假设。


*当FDI流入是唯一解释变量时，FDI流入的滞后一期即作为FDI流入的工具变量

use 1.dta, clear
xtset id year 
qui tab year, gen(yr)

reg intea fdi ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag
ivregress 2sls intea ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag  (fdi=fdi_lag),first r
*F统计量为12，且工具变量fdi_lag与fdi呈明显的正向回归关系，两者的相关系数为0.637，适合成为fdi的工具变量。
corr fdi fdi_lag
estat endogenous  

*稳健的DWH检验在10%的水平上拒绝了fdi是外生变量的假设，表明模型存在内生性。手动执行稳健DWH检验结果，发现F=4.8e+16，P=0.0000，再次表明fdi为内生变量。
quietly predict v1hat,res
quietly reg intea fdi ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag v1hat,r
test v1hat

ivregress 2sls intea ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag (fdi=fdi_lag),first r
estat firststage,forcenonrobust all
*联合显著性F统计量为35.7489，明显高于16.38。shea偏R2为0.3518，拒绝fdi_lag是弱工具变量的假设。
*可见，fdi为内生变量且存在fdi_lag的工具变量，通过IV估计可以得到比OLS估计更合理的结果。



*当FDI流入和制度环境同时为解释变量时，取FDI流入的滞后一期作为FDI流入的工具变量

*采用2sls方法.首先检验工具变量的有效性，并做内生性检验

reg intea fdi ins ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag 
ivregress 2sls intea ins ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag (fdi=fdi_lag),first r
estat endogenous
quietly predict v2hat,res
quietly reg intea fdi ins ln_gdp_lag gdpgr_lag  ln_gni_lag ln_trade_lag v2hat,r
test v2hat
*稳健的DWH检验约在10%的水平上拒绝了fdi是外生变量的假设，表明模型存在内生性
ivregress 2sls intea ins ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag (fdi=fdi_lag),first r
estat firststage,forcenonrobust all
*联合显著性F统计量为50.0741，明显高于16.38。shea偏R2为0.429，拒绝fdi_lag是弱工具变量的假设。


ivregress 2sls intea reg ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag (fdi=fdi_lag),first r
estat endogenous  
quietly predict v3hat,res
quietly reg intea fdi reg ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag v3hat,r
test v3hat
ivregress 2sls intea reg ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag (fdi=fdi_lag),first r
estat firststage,forcenonrobust all
*联合显著性F统计量为47.2432，明显高于16.38。shea偏R2为0.41，拒绝fdi_lag是弱工具变量的假设。


ivregress 2sls intea nor ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag (fdi=fdi_lag),first r
estat endogenous  
quietly predict v4hat,res
quietly reg intea fdi nor ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag v4hat,r
test v4hat
ivregress 2sls intea nor ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag (fdi=fdi_lag),first r
estat firststage,forcenonrobust all
*联合显著性F统计量为50.2891，明显高于16.38。shea偏R2为0.4346，拒绝fdi_lag是弱工具变量的假设。


ivregress 2sls intea cog ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag (fdi=fdi_lag),first r
estat endogenous  
quietly predict v5hat,res
quietly reg intea fdi cog ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag v5hat,r
test v5hat
ivregress 2sls intea cog ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag (fdi=fdi_lag),first r
estat firststage,forcenonrobust all
*联合显著性F统计量为51.2372，明显高于16.38。shea偏R2为0.4381，拒绝fdi_lag是弱工具变量的假设。



*第一阶段，用FDI流入的滞后一期、其他解释变量和控制变量，对FDI流入进行回归并取其拟合值

reg fdi ins ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag fdi_lag yr1-yr10,r 
predict fdipi

reg fdi reg ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag fdi_lag yr1-yr10,r 
predict fdipr

reg fdi nor ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag fdi_lag yr1-yr10,r 
predict fdipn

reg fdi cog ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag fdi_lag yr1-yr10,r 
predict fdipc

*第二阶段，对拟合值进行中心化，并与中心化后的制度变量及其各个维度分别形成交乘项，然后分别取这些交乘项的滞后一期，再替代模型中的原交乘项重新回归

center fdipi fdipr fdipc fdipn

g c_fdipins=c_fdipi*c_ins
g c_fdipins_lag=L.c_fdipins

g c_fdipreg=c_fdipr*c_reg
g c_fdipreg_lag=L.c_fdipreg

g c_fdipnor=c_fdipn*c_nor
g c_fdipnor_lag=L.c_fdipnor

g c_fdipcog=c_fdipc*c_cog
g c_fdipcog_lag=L.c_fdipcog

ivregress 2sls intea ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag (fdi=fdi_lag) yr1-yr10,r
est store model_1

reg intea fdipi ins c_fdipins_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,r
est store model_2

reg intea fdipi reg c_fdipreg_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,r
est store model_3

reg intea fdipi nor c_fdipnor_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,r
est store model_4

reg intea fdipi cog c_fdipcog_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,r
est store model_5

local m "model_1  model_2  model_3  model_4  model_5"
esttab `m' , mtitle(`m')  nogap compress s(N r2) star(* 0.1 ** 0.05 *** 0.01) ///
             t(%6.2f) b(%6.4f) replace
esttab `m'   using table4-1.csv, mtitle(`m')  nogap compress s(N r2) ///
             t(%6.2f) b(%6.4f) star(* 0.1 ** 0.05 *** 0.01) replace 




*-----------------------------------------------------------------------------------------------------------------
*-----------------------------------------------------------------------------------------------------------------
****************************************第四部分：稳健性检验***************************************
*-----------------------------------------------------------------------------------------------------------------
*-----------------------------------------------------------------------------------------------------------------


*(1)用FDI流入的存量代替流量，结果仍较理想，FDI流入仍然正向调节总的制度环境与国际创业的关系

use 1.dta, clear
xtset id year 

reg intea fdis ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag
est store model_1

reg intea fdis ins c_insfdis_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag
est store model_2

reg intea fdis reg c_regfdis_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag
est store model_3

reg intea fdis nor c_norfdis_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag
est store model_4

reg intea fdis cog c_cogfdis_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag
est store model_5

local m "model_1  model_2  model_3  model_4  model_5"
esttab `m' , mtitle(`m')  nogap compress s(N r2) star(* 0.1 ** 0.05 *** 0.01) ///
             t(%6.2f) b(%6.4f) replace
esttab `m'   using table4-2.csv, mtitle(`m')  nogap compress s(N r2) ///
             t(%6.2f) b(%6.4f) star(* 0.1 ** 0.05 *** 0.01) replace 

			 
*(2)平均值回归，用三期平均值代替水平值进行回归

use 1.dta, clear
xtset id year 
qui tab year, gen(yr)

g intea3=(intea[_n-1]+intea[_n]+intea[_n+1])/3
g ins3=(ins[_n-1]+ins[_n]+ins[_n+1])/3
g regM3=(reg[_n-1]+reg[_n]+reg[_n+1])/3
g nor3=(nor[_n-1]+nor[_n]+nor[_n+1])/3
g cog3=(cog[_n-1]+cog[_n]+cog[_n+1])/3
g fdi3=(fdi[_n-1]+fdi[_n]+fdi[_n+1])/3

reg intea3 fdi3 ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,r
est store model_1

reg intea3 fdi3 ins3  ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,r
est store model_2

reg intea3 fdi3 regM3 ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,r
est store model_3

reg intea3 fdi3 nor3  ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,r
est store model_4

reg intea3 fdi3 cog3  ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,r
est store model_5

local m "model_1  model_2  model_3  model_4  model_5"
esttab `m' , mtitle(`m')  nogap compress s(N r2) star(* 0.1 ** 0.05 *** 0.01) ///
             t(%6.2f) b(%6.4f) replace
esttab `m'   using table4-3.csv, mtitle(`m')  nogap compress s(N r2) ///
             t(%6.2f) b(%6.4f) star(* 0.1 ** 0.05 *** 0.01) replace 

	


*(3)改变回归方法

use 1.dta, clear
xtset id year 
qui tab year, gen(yr)

*模型检验：模型存在异方差与序列相关问题****

xtreg intea fdi ins c_insfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,fe r
xttest3

reg intea fdi ins c_insfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10, r
abar

*采用xtgls回归，同时考虑截面异方差和自相关，且各截面自相关系数各不相同****

xtgls intea fdi ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,panel(het) corr(psar1) force 
est store model_1

xtgls intea fdi ins c_insfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,panel(het) corr(psar1) force 
est store model_2

xtgls intea fdi reg c_regfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,panel(het) corr(psar1) force 
est store model_3

xtgls intea fdi nor c_norfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,panel(het) corr(psar1) force 
est store model_4

xtgls intea fdi cog c_cogfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,panel(het) corr(psar1) force 
est store model_5

local m "model_1  model_2  model_3  model_4  model_5"
esttab `m' , mtitle(`m')  nogap compress s(N) star(* 0.1 ** 0.05 *** 0.01) ///
             t(%6.2f) b(%6.4f) replace
esttab `m'   using table4-4.csv, mtitle(`m')  nogap compress s(N) ///
             t(%6.2f) b(%6.4f) star(* 0.1 ** 0.05 *** 0.01) replace 





*-----------------------------------------------------------------------------------------------------------------
*-----------------------------------------------------------------------------------------------------------------
****************************************第五部分：机制分析——表5、表6、表7*****************************************
*-----------------------------------------------------------------------------------------------------------------
*-----------------------------------------------------------------------------------------------------------------

*按经济发展程度将样本分为发达国家和发展中国家

use 1.dta, clear
xtset id year 


g income="0" if  ( country=="Malaysia" |  country=="China"| country=="Thailand"|  ///
                  country=="Uganda"|  country=="South Africa"|country=="Iran"| country=="United Arab Emirates" | ///
				 country=="Bosnia and Herzegovina" |  country=="Croatia"|country=="Latvia" |  ///
                       country=="Macedonia" |country=="Slovenia" |country=="Russia" |  country=="Turkey"|  ///
                   country=="Chile" |country=="Colombia" |country=="Ecuador"  |country=="Argentina"|  ///
                      country=="Brazil" | country=="Guatemala" | country=="Trinidad and Tobago" |country=="Jamaica" |  ///
                      country=="Panama" | country=="Peru" | country=="Uruguay"| country=="Venezuela" |country=="Mexico" )
					  
					  
replace income="1" if  ( country=="United Kingdom"|country=="Hungary"|  ///   
                     country=="Belgium"| country=="Denmark" |country=="Canada"|  country=="United States" |  /// 
                     country=="Finland" | country=="France" | country=="Netherlands" |   ///
                     country=="Germany"| country=="Greece" | country=="Iceland"  | country=="Ireland" | country=="Italy" |  /// 
					  country=="Norway" |country=="Poland"|country=="Portugal"|  /// 
					 country=="Spain" | country=="Sweden" |country=="Australia" |country=="Singapore"| ///  				 
				     country=="Switzerland" | country=="Taiwan"|country=="South Korea" |country=="Israel")  
					 
save 2.dta,replace


*总样本检验 

use 2.dta,clear
xtset id year 
qui tab year, gen(yr)
 
reg intea fdi ins c_fearfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10
est store model_1

reg intea fdi reg c_fearfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10
est store model_2

reg intea fdi nor c_fearfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10
est store model_3

reg intea fdi cog c_fearfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10
est store model_4

reg intea fdi ins c_rdfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10
est store model_5

reg intea fdi reg c_rdfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10
est store model_6

reg intea fdi nor c_rdfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10
est store model_7

reg intea fdi cog c_rdfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10
est store model_8


local m "model_1  model_2  model_3  model_4  model_5 model_6  model_7  model_8"
esttab `m' , mtitle(`m')  nogap compress s(N r2) star(* 0.1 ** 0.05 *** 0.01) ///
             t(%6.2f) b(%6.4f) replace
esttab `m'   using table5.csv, mtitle(`m')  nogap compress s(N r2) ///
             t(%6.2f) b(%6.4f) star(* 0.1 ** 0.05 *** 0.01) replace 

*创业失败惧怕率：外资流入通过降低创业失败惧怕率正向调节总的制度环境与国际创业的关系

*研发水平：调节效应不显著。


*分样本检验 

use 2.dta,clear
xtset id year 
qui tab year, gen(yr)
preserve 

keep if income=="1" 
 
reg intea fdi ins c_fearfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,r
est store model_1

reg intea fdi reg c_fearfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,r
est store model_2

reg intea fdi nor c_fearfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,r
est store model_3

reg intea fdi cog c_fearfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,r
est store model_4
restore

*创业失败惧怕率：在发达国家，FDI流入对总的制度环境与国际创业关系的调节效应显著


xtset id year 
keep if income=="0" 

reg intea fdi ins c_fearfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,r
est store model_5

reg intea fdi reg c_fearfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,r
est store model_6

reg intea fdi nor c_fearfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,r
est store model_7

reg intea fdi cog c_fearfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,r
est store model_8

local m "model_1  model_2  model_3  model_4  model_5 model_6  model_7  model_8"
esttab `m' , mtitle(`m')  nogap compress s(N r2) star(* 0.1 ** 0.05 *** 0.01) ///
             t(%6.2f) b(%6.4f) replace
esttab `m'   using table6.csv, mtitle(`m')  nogap compress s(N r2) ///
             t(%6.2f) b(%6.4f) star(* 0.1 ** 0.05 *** 0.01) replace 

					  
*创业失败惧怕率：在发展中国家，FDI流入的调节效应不显著					  
	


*研发水平：在发达国家，这种调节效应显著；但在发展中国家，这种调节效应不显著。

use 2.dta,clear
xtset id year 
qui tab year, gen(yr)
preserve 

keep if income=="1" 
 
reg intea fdi ins c_rdfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,r
est store model_1

reg intea fdi reg c_rdfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,r
est store model_2

reg intea fdi nor c_rdfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,r
est store model_3

reg intea fdi cog c_rdfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,r
est store model_4
restore

xtset id year 
keep if income=="0" 

reg intea fdi ins c_rdfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,r
est store model_5

reg intea fdi reg c_rdfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,r
est store model_6

reg intea fdi nor c_rdfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,r
est store model_7

reg intea fdi cog c_rdfdi_lag ln_gdp_lag gdpgr_lag ln_gni_lag ln_trade_lag yr1-yr10,r
est store model_8

local m "model_1  model_2  model_3  model_4  model_5 model_6  model_7  model_8"
esttab `m' , mtitle(`m')  nogap compress s(N r2) star(* 0.1 ** 0.05 *** 0.01) ///
             t(%6.2f) b(%6.4f) replace
esttab `m'   using table7.csv, mtitle(`m')  nogap compress s(N r2) ///
             t(%6.2f) b(%6.4f) star(* 0.1 ** 0.05 *** 0.01) replace 





